// ignore_for_file: public_member_api_docs, constant_identifier_names

import 'package:healthrian_common_support/healthrian_common_support.dart';

class Commands {
  static const List<int> _PREAMBLE = [
    0x48,
    0x52,
  ];

  static List<int> _size(List<int> payload) {
    return [
      payload.length,
    ];
  }

  // CRC16 CCITT-FALSE
  static List<int> _crc(List<int> payload) {
    return Crc16.getCcittFalse(payload);
  }

  static List<int> _packet(List<int> command, [List<int>? data]) {
    final payload = _payload(command, data ?? []);
    return [
      ..._PREAMBLE,
      ..._size(payload),
      ...payload,
      ..._crc(payload),
    ];
  }

  static List<int> _payload(List<int> command, List<int> data) {
    return [
      ...command,
      ...data,
    ];
  }

  static List<int> get _getDataDT {
    final dateTime = DateTime.now();
    return [
      dateTime.year >> 8,
      dateTime.year & 0xFF,
      dateTime.month,
      dateTime.day,
      dateTime.hour,
      dateTime.minute,
      dateTime.second,
    ];
  }

  static List<int> get packetSetHolterTime => _packet(
        _COMMAND_SET_HOLTER_TIME,
        _getDataDT,
      );

  static List<int> get packetReadEcg => _packet(_COMMAND_READ_ECG);

  static List<int> get packetReadOxi => _packet(_COMMAND_READ_PULSE_OXI);

  static List<int> get packetStopEcg => _packet(_COMMAND_STOP_ECG);

  static List<int> get packetStopOxi => _packet(_COMMAND_STOP_PULSE_OXI);

  static List<int> get packetFirmUpdate => _packet(_COMMAND_FIRM_UPDATE);

  static const List<int> _COMMAND_READ_ECG = [
    0x11,
  ];

  static const List<int> _COMMAND_READ_PULSE_OXI = [
    0x20,
  ];

  static const List<int> _COMMAND_STOP_ECG = [
    0x81,
  ];

  static const List<int> _COMMAND_STOP_PULSE_OXI = [
    0x90,
  ];

  static const List<int> _COMMAND_FIRM_UPDATE = [
    0xFA,
  ];

  static const List<int> _COMMAND_SET_HOLTER_TIME = [
    0x80,
  ];
}
